@@ -1,21 +1,10 @@
 /*
-   This file is part of the KDE project
-   Copyright (C) 2004 David Faure <faure@kde.org>
-   Copyright (C) 2009 Thomas McGuire <mcguire@kde.org>
+    This file is part of the KDE project
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
+    SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 //krazy:excludeall=contractions
 
@@ -543,8 +532,9 @@ void KEmailAddressTest::testQuoteIfNecessary()
 {
     QFETCH(QString, input);
     QFETCH(QString, expResult);
-
-    QCOMPARE(quoteNameIfNecessary(input), expResult);
+    QBENCHMARK {
+        QCOMPARE(quoteNameIfNecessary(input), expResult);
+    }
 }
 
 void KEmailAddressTest::testQuoteIfNecessary_data()
@@ -563,6 +553,26 @@ void KEmailAddressTest::testQuoteIfNecessary_data()
     QTest::newRow("") << "\"don't quote again\"" << "\"don't quote again\"";
     QTest::newRow("") << "\"leading double quote" << "\"\\\"leading double quote\"";
     QTest::newRow("") << "trailing double quote\"" << "\"trailing double quote\\\"\"";
+#if 0
+    BEFORE: static QRegularExpression
+      RESULT : KEmailAddressTest::testQuoteIfNecessary():
+      0.015 msecs per iteration (total: 64, iterations: 4096)
+      0.019 msecs per iteration (total: 80, iterations: 4096)
+      0.019 msecs per iteration (total: 81, iterations: 4096)
+      0.0244 msecs per iteration (total: 100, iterations: 4096)
+      0.0079 msecs per iteration (total: 65, iterations: 8192)
+      0.020 msecs per iteration (total: 82, iterations: 4096)
+      0.020 msecs per iteration (total: 82, iterations: 4096)
+
+      AFTER:
+      RESULT : KEmailAddressTest::testQuoteIfNecessary():
+      0.0097 msecs per iteration (total: 80, iterations: 8192)
+      0.010 msecs per iteration (total: 82, iterations: 8192)
+      0.015 msecs per iteration (total: 63, iterations: 4096)
+      0.0076 msecs per iteration (total: 63, iterations: 8192)
+      0.0098 msecs per iteration (total: 81, iterations: 8192)
+      0.010 msecs per iteration (total: 87, iterations: 8192)
+#endif
 }
 
 void KEmailAddressTest::testMailtoUrls()
